import ctypes
import os
import re
import unicodedata

from gimpfu import *
import gtk


def slugify(value):
    """
    Normalizes string, converts to lowercase, removes non-alpha characters,
    and converts spaces to hyphens.

    Based on code in: Django
    """
    value = unicodedata.normalize('NFKD', unicode(value))
    value = value.encode('ascii', 'ignore')
    value = re.sub('[^\w\s-]', '', value).strip().lower()
    value = re.sub('[-\s]+', '-', value)
    return value

def get_dir() :
        MessageBox = ctypes.windll.user32.MessageBoxA
        response = ""

        # Check for new pygtk: this is new class in PyGtk 2.4
        if (gtk.pygtk_version < (2, 3, 90)) :
                MessageBox(None, "This plugin requires PyGtk 2.3.90 or later", "Error", 0)
                return response

        dialog = gtk.FileChooserDialog(
                "Dump to...",
                None,
                gtk.FILE_CHOOSER_ACTION_OPEN,
                (
                        gtk.STOCK_CANCEL,
                        gtk.RESPONSE_CANCEL,
                        gtk.STOCK_OPEN,
                        gtk.RESPONSE_OK
                )
        )
        dialog.set_default_response(gtk.RESPONSE_OK)
        dialog.set_action(gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)

        if (dialog.run() == gtk.RESPONSE_OK) :
                response = dialog.get_filename()
        dialog.destroy()

        return response

def dump_pdb() :
        MessageBox = ctypes.windll.user32.MessageBoxA

        rootDirectory = get_dir()
        if("" == rootDirectory) :
                return None

        for name in gimp.pdb.query() :
                outDirectory = os.path.join(rootDirectory, name.split('-')[0].capitalize())
                if not os.path.isdir(outDirectory):
                  os.mkdir(outDirectory)
                plugin = pdb[name]
                outFile = os.path.join(
                        outDirectory,
                        "%s%s" % (slugify(name), ".txt")
                )
                with open(outFile, 'w') as f :
                        f.write("author:\n%s\n" % plugin.proc_author)
                        f.write("date:\n%s\n" % plugin.proc_date)
                        f.write("copyright:\n%s\n" % plugin.proc_copyright)
                        f.write("blurb:\n%s\n" % plugin.proc_blurb)
                        f.write("help:\n%s\n" % plugin.proc_help)
                        f.write("parameters[%d]:\n" % plugin.nparams)
                        try:
                          for p in plugin.params:
                            f.write("\n\t")
                            f.write("%d %s" % (p[0] , p[1]))
                        except Exception, e:
                          pdb.gimp_message(e)
                        f.write("\nreturn[%d]:\n" % plugin.nreturn_vals)    
                        for r in plugin.return_vals:
                            f.write("\n\t")
                            f.write("%d %s %s" % (r[0] , r[1] ,r[2]))
                          

        return None

register(
        # name
        "dump-pdb",
        # blurb
        "Export PDB database to plain files",
        # help
        "",
        # author
        "Codefox & Gandalf",
        # copyright
        "MIT license",
        # date
        "October 25, 2013",
        # menu path
        "<Toolbox>/Help/Procedure Dumper",
        # image types
        None,
        # params
        [],
        # results
        [],
        # function
        dump_pdb
)

main()
